@@ -66,7 +66,7 @@ class BasePayment(models.Model):
 
     def save(self, *args, **kwargs):
         if not self.token:
-            for _i in xrange(100):
+            for _i in range(100):
                 token = str(uuid4())
                 if not type(self).objects.filter(token=token).exists():
                     self.token = token
