@@ -9,5 +9,5 @@ class CreditCardNumberWidget(TextInput):
         if value:
             value = re.sub('[\s-]', '', value)
             value = ' '.join([value[i: i + 4]
-                              for i in xrange(0, len(value), 4)])
+                              for i in range(0, len(value), 4)])
         return super(CreditCardNumberWidget, self).render(name, value, attrs)
